==> oceanbolt.sdk-0.4.1.tar.gz: oceanbolt.sdk-0.4.1/oceanbolt/com/entities_v3/services/entity_service/transports/base.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
import pkg_resources

import google.auth  # type: ignore
import google.api_core
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1
from google.api_core import retry as retries
from google.auth import credentials as ga_credentials  # type: ignore
from google.oauth2 import service_account # type: ignore

from oceanbolt.com.entities_v3.types import service

try:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
        gapic_version=pkg_resources.get_distribution(
            'oceanbolt-com-entities',
        ).version,
    )
except pkg_resources.DistributionNotFound:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()


class EntityServiceTransport(abc.ABC):
    """Abstract transport class for EntityService."""

    AUTH_SCOPES = (
    )

    DEFAULT_HOST: str = 'api.oceanbolt.com'
    def __init__(
            self, *,
            host: str = DEFAULT_HOST,
            credentials: ga_credentials.Credentials = None,
            credentials_file: Optional[str] = None,
            scopes: Optional[Sequence[str]] = None,
            quota_project_id: Optional[str] = None,
            client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
            always_use_jwt_access: Optional[bool] = False,
            api_audience: Optional[str] = None,
            **kwargs,
            ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to.
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
        """

        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}

        # Save the scopes.
        self._scopes = scopes

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs("'credentials_file' and 'credentials' are mutually exclusive")

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                                credentials_file,
                                **scopes_kwargs,
                                quota_project_id=quota_project_id
                            )
        elif credentials is None:
            credentials, _ = google.auth.default(**scopes_kwargs, quota_project_id=quota_project_id)
            # Don't apply audience if the credentials file passed from user.
            if hasattr(credentials, "with_gdch_audience"):
                credentials = credentials.with_gdch_audience(api_audience if api_audience else host)

        # If the credentials are service account credentials, then always try to use self signed JWT.
        if always_use_jwt_access and isinstance(credentials, service_account.Credentials) and hasattr(service_account.Credentials, "with_always_use_jwt_access"):
            credentials = credentials.with_always_use_jwt_access(True)

        # Save the credentials.
        self._credentials = credentials

        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ':' not in host:
            host += ':443'
        self._host = host

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.list_segments: gapic_v1.method.wrap_method(
                self.list_segments,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_zones: gapic_v1.method.wrap_method(
                self.list_zones,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_zones_with_polygons: gapic_v1.method.wrap_method(
                self.list_zones_with_polygons,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_regions: gapic_v1.method.wrap_method(
                self.list_regions,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_commodities: gapic_v1.method.wrap_method(
                self.list_commodities,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_countries: gapic_v1.method.wrap_method(
                self.list_countries,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_regions_with_polygons: gapic_v1.method.wrap_method(
                self.list_regions_with_polygons,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_ports: gapic_v1.method.wrap_method(
                self.list_ports,
                default_timeout=None,
                client_info=client_info,
            ),
            self.search_polygons: gapic_v1.method.wrap_method(
                self.search_polygons,
                default_timeout=None,
                client_info=client_info,
            ),
            self.search_vessels: gapic_v1.method.wrap_method(
                self.search_vessels,
                default_timeout=None,
                client_info=client_info,
            ),
         }

    def close(self):
        """Closes resources associated with the transport.

       .. warning::
            Only call this method if the transport is NOT shared
            with other clients - this may cause errors in other clients!
        """
        raise NotImplementedError()

    @property
    def list_segments(self) -> Callable[
            [service.ListSegmentsRequest],
            Union[
                service.ListSegmentsResponse,
                Awaitable[service.ListSegmentsResponse]
            ]]:
        raise NotImplementedError()

    @property
    def list_zones(self) -> Callable[
            [service.ListZonesRequest],
            Union[
                service.ListTonnageZonesResponse,
                Awaitable[service.ListTonnageZonesResponse]
            ]]:
        raise NotImplementedError()

    @property
    def list_zones_with_polygons(self) -> Callable[
            [service.ListZonesRequest],
            Union[
                service.ListTonnageZonesWithPolygonsResponse,
                Awaitable[service.ListTonnageZonesWithPolygonsResponse]
            ]]:
        raise NotImplementedError()

    @property
    def list_regions(self) -> Callable[
            [service.ListRegionsRequest],
            Union[
                service.ListRegionsResponse,
                Awaitable[service.ListRegionsResponse]
            ]]:
        raise NotImplementedError()

    @property
    def list_commodities(self) -> Callable[
            [service.ListCommoditiesRequest],
            Union[
                service.ListCommoditiesResponse,
                Awaitable[service.ListCommoditiesResponse]
            ]]:
        raise NotImplementedError()

    @property
    def list_countries(self) -> Callable[
            [service.ListCountriesRequest],
            Union[
                service.ListCountriesResponse,
                Awaitable[service.ListCountriesResponse]
            ]]:
        raise NotImplementedError()

    @property
    def list_regions_with_polygons(self) -> Callable[
            [service.ListRegionsRequest],
            Union[
                service.ListRegionsWithPolygonResponse,
                Awaitable[service.ListRegionsWithPolygonResponse]
            ]]:
        raise NotImplementedError()

    @property
    def list_ports(self) -> Callable[
            [service.ListPortsRequest],
            Union[
                service.ListPortsResponse,
                Awaitable[service.ListPortsResponse]
            ]]:
        raise NotImplementedError()

    @property
    def search_polygons(self) -> Callable[
            [service.SearchRequest],
            Union[
                service.SearchPolygonsResponse,
                Awaitable[service.SearchPolygonsResponse]
            ]]:
        raise NotImplementedError()

    @property
    def search_vessels(self) -> Callable[
            [service.SearchRequest],
            Union[
                service.SearchVesselsResponse,
                Awaitable[service.SearchVesselsResponse]
            ]]:
        raise NotImplementedError()

    @property
    def kind(self) -> str:
        raise NotImplementedError()


__all__ = (
    'EntityServiceTransport',
)

==> oceanbolt.sdk-0.5.1.tar.gz: oceanbolt.sdk-0.5.1/oceanbolt/com/entities_v3/services/entity_service/transports/base.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union

from oceanbolt.com.entities_v3 import gapic_version as package_version

import google.auth  # type: ignore
import google.api_core
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1
from google.api_core import retry as retries
from google.auth import credentials as ga_credentials  # type: ignore
from google.oauth2 import service_account # type: ignore

from oceanbolt.com.entities_v3.types import service

DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(gapic_version=package_version.__version__)


class EntityServiceTransport(abc.ABC):
    """Abstract transport class for EntityService."""

    AUTH_SCOPES = (
    )

    DEFAULT_HOST: str = 'api.oceanbolt.com'
    def __init__(
            self, *,
            host: str = DEFAULT_HOST,
            credentials: Optional[ga_credentials.Credentials] = None,
            credentials_file: Optional[str] = None,
            scopes: Optional[Sequence[str]] = None,
            quota_project_id: Optional[str] = None,
            client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
            always_use_jwt_access: Optional[bool] = False,
            api_audience: Optional[str] = None,
            **kwargs,
            ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to.
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
        """

        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}

        # Save the scopes.
        self._scopes = scopes

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs("'credentials_file' and 'credentials' are mutually exclusive")

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                                credentials_file,
                                **scopes_kwargs,
                                quota_project_id=quota_project_id
                            )
        elif credentials is None:
            credentials, _ = google.auth.default(**scopes_kwargs, quota_project_id=quota_project_id)
            # Don't apply audience if the credentials file passed from user.
            if hasattr(credentials, "with_gdch_audience"):
                credentials = credentials.with_gdch_audience(api_audience if api_audience else host)

        # If the credentials are service account credentials, then always try to use self signed JWT.
        if always_use_jwt_access and isinstance(credentials, service_account.Credentials) and hasattr(service_account.Credentials, "with_always_use_jwt_access"):
            credentials = credentials.with_always_use_jwt_access(True)

        # Save the credentials.
        self._credentials = credentials

        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ':' not in host:
            host += ':443'
        self._host = host

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.list_segments: gapic_v1.method.wrap_method(
                self.list_segments,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_zones: gapic_v1.method.wrap_method(
                self.list_zones,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_zones_with_polygons: gapic_v1.method.wrap_method(
                self.list_zones_with_polygons,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_regions: gapic_v1.method.wrap_method(
                self.list_regions,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_commodities: gapic_v1.method.wrap_method(
                self.list_commodities,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_countries: gapic_v1.method.wrap_method(
                self.list_countries,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_regions_with_polygons: gapic_v1.method.wrap_method(
                self.list_regions_with_polygons,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_ports: gapic_v1.method.wrap_method(
                self.list_ports,
                default_timeout=None,
                client_info=client_info,
            ),
            self.search_polygons: gapic_v1.method.wrap_method(
                self.search_polygons,
                default_timeout=None,
                client_info=client_info,
            ),
            self.search_vessels: gapic_v1.method.wrap_method(
                self.search_vessels,
                default_timeout=None,
                client_info=client_info,
            ),
         }

    def close(self):
        """Closes resources associated with the transport.

       .. warning::
            Only call this method if the transport is NOT shared
            with other clients - this may cause errors in other clients!
        """
        raise NotImplementedError()

    @property
    def list_segments(self) -> Callable[
            [service.ListSegmentsRequest],
            Union[
                service.ListSegmentsResponse,
                Awaitable[service.ListSegmentsResponse]
            ]]:
        raise NotImplementedError()

    @property
    def list_zones(self) -> Callable[
            [service.ListZonesRequest],
            Union[
                service.ListTonnageZonesResponse,
                Awaitable[service.ListTonnageZonesResponse]
            ]]:
        raise NotImplementedError()

    @property
    def list_zones_with_polygons(self) -> Callable[
            [service.ListZonesRequest],
            Union[
                service.ListTonnageZonesWithPolygonsResponse,
                Awaitable[service.ListTonnageZonesWithPolygonsResponse]
            ]]:
        raise NotImplementedError()

    @property
    def list_regions(self) -> Callable[
            [service.ListRegionsRequest],
            Union[
                service.ListRegionsResponse,
                Awaitable[service.ListRegionsResponse]
            ]]:
        raise NotImplementedError()

    @property
    def list_commodities(self) -> Callable[
            [service.ListCommoditiesRequest],
            Union[
                service.ListCommoditiesResponse,
                Awaitable[service.ListCommoditiesResponse]
            ]]:
        raise NotImplementedError()

    @property
    def list_countries(self) -> Callable[
            [service.ListCountriesRequest],
            Union[
                service.ListCountriesResponse,
                Awaitable[service.ListCountriesResponse]
            ]]:
        raise NotImplementedError()

    @property
    def list_regions_with_polygons(self) -> Callable[
            [service.ListRegionsRequest],
            Union[
                service.ListRegionsWithPolygonResponse,
                Awaitable[service.ListRegionsWithPolygonResponse]
            ]]:
        raise NotImplementedError()

    @property
    def list_ports(self) -> Callable[
            [service.ListPortsRequest],
            Union[
                service.ListPortsResponse,
                Awaitable[service.ListPortsResponse]
            ]]:
        raise NotImplementedError()

    @property
    def search_polygons(self) -> Callable[
            [service.SearchRequest],
            Union[
                service.SearchPolygonsResponse,
                Awaitable[service.SearchPolygonsResponse]
            ]]:
        raise NotImplementedError()

    @property
    def search_vessels(self) -> Callable[
            [service.SearchRequest],
            Union[
                service.SearchVesselsResponse,
                Awaitable[service.SearchVesselsResponse]
            ]]:
        raise NotImplementedError()

    @property
    def kind(self) -> str:
        raise NotImplementedError()


__all__ = (
    'EntityServiceTransport',
)
